@@ -16,7 +16,7 @@ from epyqlib.tabs.files.filesview import Cols, get_values
 from epyqlib.tabs.files.log_manager import LogManager, PendingLog
 from epyqlib.tabs.files.sync_config import SyncConfig, Vars
 from epyqlib.utils.twisted import errbackhook
-import twisted.internet
+from twisted.internet import reactor
 from twisted.internet.error import DNSLookupError
 from twisted.internet.task import deferLater
 from typing import Dict
@@ -328,16 +328,6 @@ class FilesController:
             print(f"{self._tag} Unable to login to AWS. Setting offline mode to true.")
             self.set_offline(True)
 
-    async def logout_clicked(self):
-        self.aws_login_manager.log_user_out()
-        print(f"{self._tag} Logging out from AWS. Setting offline mode to true.")
-        self.set_offline(True)
-
-    async def serial_number_from_parameters_clicked(self):
-        self._serial_number = self._device_interface.get_serial_number_from_parameters()
-        self.view.serial_number.setText(self._serial_number)
-        await self._get_id_for_serial_number(self._serial_number)
-
     def open_file(self, row: QTreeWidgetItem):
         file_hash = self._get_mapping_for_row(row).association["file"]["hash"]
         file_path = self.cache_manager.get_file_path(file_hash)
@@ -551,9 +541,7 @@ class FilesController:
             self.aws_login_manager.refresh(force=True)
             self.api.set_id_token(self.aws_login_manager.get_id_token())
             deferLater(
-                twisted.internet.reactor,
-                self.aws_login_manager._cognito_helper._expires_in,
-                _refresh,
+                reactor, self.aws_login_manager._cognito_helper._expires_in, _refresh
             )
 
         _refresh()
@@ -649,8 +637,6 @@ class FilesController:
         else:
             self.view.show_logged_in_status(True, self.aws_login_manager.get_username())
 
-        self.view.btn_sync_now.setDisabled(is_offline)
-
     async def _get_id_for_serial_number(self, serial_number: str):
         if serial_number not in self._inverter_id_lookup and not self._is_offline:
             inverter = await self.api.get_inverter_by_serial(serial_number)
