@@ -15,7 +15,7 @@ import epyqlib.pm.parametermodel
 import epyqlib.tests.test_attrsmodel
 
 
-with open(pathlib.Path(__file__).with_suffix('.json')) as f:
+with open(pathlib.Path(__file__).with_suffix(".json")) as f:
     serialized_sample = f.read()
 
 
@@ -23,7 +23,7 @@ with open(pathlib.Path(__file__).with_suffix('.json')) as f:
 class SampleModel:
     root = attr.ib(
         factory=lambda: epyqlib.pm.parametermodel.Root(
-            uuid='ce63b990-8061-4b9f-9ad7-d2b60fe8b4c9',
+            uuid="ce63b990-8061-4b9f-9ad7-d2b60fe8b4c9",
         ),
     )
     model = attr.ib(default=None)
@@ -47,25 +47,25 @@ class SampleModel:
 
     def fill(self):
         self.group_a = epyqlib.pm.parametermodel.Group(
-            name='Group A',
-            uuid='78fb0043-b46f-4198-86ed-3ba8d48bf4c8',
+            name="Group A",
+            uuid="78fb0043-b46f-4198-86ed-3ba8d48bf4c8",
         )
         parameter_a_a = epyqlib.pm.parametermodel.Parameter(
-            name='Parameter A A',
-            uuid='fd184494-35a2-4b3a-970c-9a3d98cc15cd',
+            name="Parameter A A",
+            uuid="fd184494-35a2-4b3a-970c-9a3d98cc15cd",
         )
         group_a_b = epyqlib.pm.parametermodel.Group(
-            name='Group A B',
-            uuid='5db07237-82c8-488f-925b-1a2a2802fb5b',
+            name="Group A B",
+            uuid="5db07237-82c8-488f-925b-1a2a2802fb5b",
         )
         parameter_b = epyqlib.pm.parametermodel.Parameter(
-            name='Parameter B',
+            name="Parameter B",
             default=42,
-            uuid='ee545382-a651-479b-9dc2-a4c3d42c230c',
+            uuid="ee545382-a651-479b-9dc2-a4c3d42c230c",
         )
         group_c = epyqlib.pm.parametermodel.Group(
-            name='Group C',
-            uuid='7878effc-2d29-4719-bf0d-192e18d0f27c',
+            name="Group C",
+            uuid="7878effc-2d29-4719-bf0d-192e18d0f27c",
         )
 
         self.root.append_child(self.group_a)
@@ -77,32 +77,29 @@ class SampleModel:
         self.root.append_child(group_c)
 
         self.enumerations = epyqlib.pm.parametermodel.Enumerations(
-            name='Enumerations',
-            uuid='4f71f673-af26-4c70-8d3e-910902163e98',
+            name="Enumerations",
+            uuid="4f71f673-af26-4c70-8d3e-910902163e98",
         )
         self.root.append_child(self.enumerations)
 
         self.letters_enumeration = epyqlib.pm.parametermodel.Enumeration(
-            name='Letters',
-            uuid='fd1b8036-8aef-4914-9165-ed3118bd8ecd',
+            name="Letters",
+            uuid="fd1b8036-8aef-4914-9165-ed3118bd8ecd",
         )
         self.enumerations.append_child(self.letters_enumeration)
         self.letters_enumerators = {
-            letter: epyqlib.pm.parametermodel.Enumerator(
-                name=letter,
-                uuid=uuid
-            )
+            letter: epyqlib.pm.parametermodel.Enumerator(name=letter, uuid=uuid)
             for letter, uuid in (
-                ('a', 'a2cf0c0c-c55a-4a0c-b830-571b5abe089b'),
-                ('b', 'effdff81-7da1-4cd8-863f-44f33c75813e'),
+                ("a", "a2cf0c0c-c55a-4a0c-b830-571b5abe089b"),
+                ("b", "effdff81-7da1-4cd8-863f-44f33c75813e"),
             )
         }
         for letter, enumerator in sorted(self.letters_enumerators.items()):
             self.letters_enumeration.append_child(enumerator)
-            
+
         self.numbers_enumeration = epyqlib.pm.parametermodel.Enumeration(
-            name='numbers',
-            uuid='86111e99-624c-499e-a560-6a77db461e43',
+            name="numbers",
+            uuid="86111e99-624c-499e-a560-6a77db461e43",
         )
         self.enumerations.append_child(self.numbers_enumeration)
         self.numbers_enumerators = {
@@ -111,142 +108,142 @@ class SampleModel:
                 uuid=uuid,
             )
             for number, uuid in (
-                ('1', '165ccc7b-7ffc-4546-add2-11f0855f86d1'),
-                ('2', '64e3e07c-dd4f-439a-850c-69508bfd545c'),
+                ("1", "165ccc7b-7ffc-4546-add2-11f0855f86d1"),
+                ("2", "64e3e07c-dd4f-439a-850c-69508bfd545c"),
             )
         }
         for number, enumerator in sorted(self.numbers_enumerators.items()):
             self.numbers_enumeration.append_child(enumerator)
 
         self.table = epyqlib.pm.parametermodel.Table(
-            name='Table A',
-            uuid='58b7bf0d-4dec-4707-a976-d49a856eb3ba',
+            name="Table A",
+            uuid="58b7bf0d-4dec-4707-a976-d49a856eb3ba",
         )
         self.group_a.append_child(self.table)
         self.table.append_child(
             epyqlib.pm.parametermodel.TableEnumerationReference(
-                name='Letters',
-                uuid='d80162ea-bd8c-4936-bca1-732b11205423',
+                name="Letters",
+                uuid="d80162ea-bd8c-4936-bca1-732b11205423",
                 enumeration_uuid=self.letters_enumeration.uuid,
             ),
         )
         self.table.append_child(
             epyqlib.pm.parametermodel.TableEnumerationReference(
-                name='Numbers',
-                uuid='3d98c907-0b81-4e29-be9b-2620ef44ce26',
+                name="Numbers",
+                uuid="3d98c907-0b81-4e29-be9b-2620ef44ce26",
                 enumeration_uuid=self.numbers_enumeration.uuid,
             ),
         )
 
         array_a = epyqlib.pm.parametermodel.Array(
-            name='Table Array A',
-            uuid='77ed47bb-fbea-4756-b1c4-2e2be02aebc7',
+            name="Table Array A",
+            uuid="77ed47bb-fbea-4756-b1c4-2e2be02aebc7",
         )
         array_a.append_child(
             epyqlib.pm.parametermodel.Parameter(
-                name='A0',
-                uuid='a32ea0c1-0838-430f-8d3c-192b5bff3047',
+                name="A0",
+                uuid="a32ea0c1-0838-430f-8d3c-192b5bff3047",
             )
         )
         array_a.length = 2
-        array_a.children[1].name = 'A1'
+        array_a.children[1].name = "A1"
         array_a.children[1].uuid = uuid.UUID(
-            '9d642888-b7f0-4d04-8ebf-10887249b179',
+            "9d642888-b7f0-4d04-8ebf-10887249b179",
         )
         self.table.append_child(array_a)
 
         array_b = epyqlib.pm.parametermodel.Array(
-            name='Table Array B',
-            uuid='acda3b53-785c-4588-8b35-d58a9f2e10a8',
+            name="Table Array B",
+            uuid="acda3b53-785c-4588-8b35-d58a9f2e10a8",
         )
         array_b.append_child(
             epyqlib.pm.parametermodel.Parameter(
-                name='B0',
-                uuid='1c7d0fac-aaa6-415b-b7c1-08d1f5d07097',
+                name="B0",
+                uuid="1c7d0fac-aaa6-415b-b7c1-08d1f5d07097",
             )
         )
         array_b.length = 2
-        array_b.children[1].name = 'B1'
+        array_b.children[1].name = "B1"
         array_b.children[1].uuid = uuid.UUID(
-            '32666885-2934-481f-88fd-7e3157f702b1',
+            "32666885-2934-481f-88fd-7e3157f702b1",
         )
         self.table.append_child(array_b)
 
         table_group_root = epyqlib.pm.parametermodel.TableGroupElement(
-            name='Tree',
-            uuid='428124a2-6fe3-4b40-9e23-f78e19c7aa7a',
+            name="Tree",
+            uuid="428124a2-6fe3-4b40-9e23-f78e19c7aa7a",
         )
 
         table_group_root_a = epyqlib.pm.parametermodel.TableGroupElement(
-            original=self.letters_enumerators['a'],
-            uuid='904d287d-2cdd-487e-ada9-ed0f8a552078',
-            path=(self.letters_enumerators['a'].uuid,),
+            original=self.letters_enumerators["a"],
+            uuid="904d287d-2cdd-487e-ada9-ed0f8a552078",
+            path=(self.letters_enumerators["a"].uuid,),
         )
         table_group_root_a_1 = epyqlib.pm.parametermodel.TableGroupElement(
-            original=self.numbers_enumerators['1'],
-            uuid='9d37bb7f-2618-4ce8-b9f9-214c19851361',
-            path=table_group_root_a.path + (self.numbers_enumerators['1'].uuid,),
+            original=self.numbers_enumerators["1"],
+            uuid="9d37bb7f-2618-4ce8-b9f9-214c19851361",
+            path=table_group_root_a.path + (self.numbers_enumerators["1"].uuid,),
         )
         table_group_root_a_1_a = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_a,
-            uuid='993ededd-6083-4c1e-aa72-bf08ee3ea61c',
+            uuid="993ededd-6083-4c1e-aa72-bf08ee3ea61c",
             path=table_group_root_a_1.path + (array_a.uuid,),
         )
         self.add_array_elements(
             array=array_a,
             group=table_group_root_a_1_a,
             uuids=[
-                '403b3a2c-f94a-490c-b112-87cdd3551e55',
-                '3fd1f0e6-09e7-413e-b169-3fafff126bbc',
+                "403b3a2c-f94a-490c-b112-87cdd3551e55",
+                "3fd1f0e6-09e7-413e-b169-3fafff126bbc",
             ],
         )
         table_group_root_a_1.append_child(table_group_root_a_1_a)
 
         table_group_root_a_1_b = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_b,
-            uuid='72ce1cf9-0c90-48e9-a37c-aee1b36fca80',
+            uuid="72ce1cf9-0c90-48e9-a37c-aee1b36fca80",
             path=table_group_root_a_1.path + (array_b.uuid,),
         )
         self.add_array_elements(
             array=array_b,
             group=table_group_root_a_1_b,
             uuids=[
-                '106cc983-0321-4ced-9e72-ab56d6bf1e7f',
-                '80fd2eb7-6c89-4b65-ad35-05d63522f991',
+                "106cc983-0321-4ced-9e72-ab56d6bf1e7f",
+                "80fd2eb7-6c89-4b65-ad35-05d63522f991",
             ],
         )
         table_group_root_a_1.append_child(table_group_root_a_1_b)
         table_group_root_a.append_child(table_group_root_a_1)
         table_group_root_a_2 = epyqlib.pm.parametermodel.TableGroupElement(
-            original=self.numbers_enumerators['2'],
-            uuid='b748bc78-0267-477e-95ec-e64a6686e010',
-            path=table_group_root_a.path + (self.numbers_enumerators['2'].uuid,),
+            original=self.numbers_enumerators["2"],
+            uuid="b748bc78-0267-477e-95ec-e64a6686e010",
+            path=table_group_root_a.path + (self.numbers_enumerators["2"].uuid,),
         )
         table_group_root_a_2_a = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_a,
-            uuid='712cda8a-4744-4da2-a1d1-1573625bbf14',
+            uuid="712cda8a-4744-4da2-a1d1-1573625bbf14",
             path=table_group_root_a_2.path + (array_a.uuid,),
         )
         self.add_array_elements(
             array=array_a,
             group=table_group_root_a_2_a,
             uuids=[
-                '290b2762-61c7-4666-8f99-af3c0113d4a3',
-                'aee3a1de-b35a-4e7b-b274-1ef6766d5889',
+                "290b2762-61c7-4666-8f99-af3c0113d4a3",
+                "aee3a1de-b35a-4e7b-b274-1ef6766d5889",
             ],
         )
         table_group_root_a_2.append_child(table_group_root_a_2_a)
         table_group_root_a_2_b = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_b,
-            uuid='e74d9047-1635-43f3-825b-6844fab96a00',
+            uuid="e74d9047-1635-43f3-825b-6844fab96a00",
             path=table_group_root_a_2.path + (array_b.uuid,),
         )
         self.add_array_elements(
             array=array_b,
             group=table_group_root_a_2_b,
             uuids=[
-                '99a1be09-c4e0-41f1-bda4-d0f139038cbf',
-                'fa79e1aa-647d-4783-8b16-fe752ac8e8c4',
+                "99a1be09-c4e0-41f1-bda4-d0f139038cbf",
+                "fa79e1aa-647d-4783-8b16-fe752ac8e8c4",
             ],
         )
         table_group_root_a_2.append_child(table_group_root_a_2_b)
@@ -254,81 +251,81 @@ class SampleModel:
         table_group_root.append_child(table_group_root_a)
 
         table_group_root_b = epyqlib.pm.parametermodel.TableGroupElement(
-            original=self.letters_enumerators['b'],
-            uuid='104d1901-524e-412b-84e7-98707dce362d',
-            path=(self.letters_enumerators['b'].uuid,),
+            original=self.letters_enumerators["b"],
+            uuid="104d1901-524e-412b-84e7-98707dce362d",
+            path=(self.letters_enumerators["b"].uuid,),
         )
         table_group_root_b_1 = epyqlib.pm.parametermodel.TableGroupElement(
-            original=self.numbers_enumerators['1'],
-            uuid='9dc75463-f6a9-411f-b0a7-5c311086ff69',
-            path=table_group_root_b.path + (self.numbers_enumerators['1'].uuid,),
+            original=self.numbers_enumerators["1"],
+            uuid="9dc75463-f6a9-411f-b0a7-5c311086ff69",
+            path=table_group_root_b.path + (self.numbers_enumerators["1"].uuid,),
         )
         table_group_root_b_1_a = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_a,
-            uuid='f0989f09-4066-4047-8d61-c134c6e1e55c',
+            uuid="f0989f09-4066-4047-8d61-c134c6e1e55c",
             path=table_group_root_b_1.path + (array_a.uuid,),
         )
         self.add_array_elements(
             array=array_a,
             group=table_group_root_b_1_a,
             uuids=[
-                'c076b3e1-a287-468c-80e4-43523a021feb',
-                '937be4d7-b578-4daa-aef0-4065198a613d',
+                "c076b3e1-a287-468c-80e4-43523a021feb",
+                "937be4d7-b578-4daa-aef0-4065198a613d",
             ],
         )
         table_group_root_b_1.append_child(table_group_root_b_1_a)
         table_group_root_b_1_b = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_b,
-            uuid='18e84e98-e8ad-4d4a-9180-951350f6590c',
+            uuid="18e84e98-e8ad-4d4a-9180-951350f6590c",
             path=table_group_root_b_1.path + (array_b.uuid,),
         )
         self.add_array_elements(
             array=array_b,
             group=table_group_root_b_1_b,
             uuids=[
-                '286079b0-6028-4959-8396-78c626cdab46',
-                'de30995a-ba26-49cf-abd0-84d3dc62b3eb',
+                "286079b0-6028-4959-8396-78c626cdab46",
+                "de30995a-ba26-49cf-abd0-84d3dc62b3eb",
             ],
         )
         table_group_root_b_1.append_child(table_group_root_b_1_b)
         table_group_root_b.append_child(table_group_root_b_1)
         table_group_root_b_2 = epyqlib.pm.parametermodel.TableGroupElement(
-            original=self.numbers_enumerators['2'],
-            uuid='1178e67b-ddda-43f3-a26a-30d0e10a2bd3',
-            path=table_group_root_b.path + (self.numbers_enumerators['2'].uuid,),
+            original=self.numbers_enumerators["2"],
+            uuid="1178e67b-ddda-43f3-a26a-30d0e10a2bd3",
+            path=table_group_root_b.path + (self.numbers_enumerators["2"].uuid,),
         )
         table_group_root_b_2_a = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_a,
-            uuid='1134bc2e-93d9-4b33-8164-dca0520f3910',
+            uuid="1134bc2e-93d9-4b33-8164-dca0520f3910",
             path=table_group_root_b_2.path + (array_a.uuid,),
         )
         self.add_array_elements(
             array=array_a,
             group=table_group_root_b_2_a,
             uuids=[
-                '6a151510-c6e5-4673-9198-d3d9fb0dfcdc',
-                'dd3887db-df84-4f5f-ae6f-98201403c1d2',
+                "6a151510-c6e5-4673-9198-d3d9fb0dfcdc",
+                "dd3887db-df84-4f5f-ae6f-98201403c1d2",
             ],
         )
         table_group_root_b_2.append_child(table_group_root_b_2_a)
         table_group_root_b_2_b = epyqlib.pm.parametermodel.TableGroupElement(
             original=array_b,
-            uuid='d84963e3-164e-4df8-9f5e-cf6717e20b0d',
+            uuid="d84963e3-164e-4df8-9f5e-cf6717e20b0d",
             path=table_group_root_b_2.path + (array_b.uuid,),
         )
         self.add_array_elements(
             array=array_b,
             group=table_group_root_b_2_b,
             uuids=[
-                'd01008cc-cef0-4c95-b642-71e974690416',
-                '2b16a382-2fa2-41b4-a0dc-161c7496d13a',
+                "d01008cc-cef0-4c95-b642-71e974690416",
+                "2b16a382-2fa2-41b4-a0dc-161c7496d13a",
             ],
         )
         table_group_root_b_2.append_child(table_group_root_b_2_b)
         table_group_root_b.append_child(table_group_root_b_2)
         table_group_root.append_child(table_group_root_b)
 
-        automatic_table_root, = [
+        (automatic_table_root,) = [
             child
             for child in self.table.children
             if isinstance(child, epyqlib.pm.parametermodel.TableGroupElement)
@@ -361,37 +358,43 @@ def sample():
     return sample_model
 
 
-default_column_index, = (
+(default_column_index,) = (
     index
     for index, column in enumerate(epyqlib.pm.parametermodel.columns)
-    if column.name == 'Default'
+    if column.name == "Default"
 )
 
 
-@pytest.mark.parametrize('column,target', (
-    (0, 'Parameter B'),
-    (default_column_index, 42),
-))
+@pytest.mark.parametrize(
+    "column,target",
+    (
+        (0, "Parameter B"),
+        (default_column_index, 42),
+    ),
+)
 def test_search_in_column(sample, column, target):
     proxy = QtCore.QSortFilterProxyModel()
     proxy.setSourceModel(sample.model.model)
 
-    index, = proxy.match(
+    (index,) = proxy.match(
         proxy.index(0, column),
         QtCore.Qt.DisplayRole,
         target,
     )
 
 
-@pytest.mark.parametrize('column,target', (
-    (0, 'Parameter B'),
-    (default_column_index, 42),
-))
+@pytest.mark.parametrize(
+    "column,target",
+    (
+        (0, "Parameter B"),
+        (default_column_index, 42),
+    ),
+)
 def test_proxy_search_in_column(sample, column, target):
     proxy = epyqlib.utils.qt.PySortFilterProxyModel(filter_column=0)
     proxy.setSourceModel(sample.model.model)
 
-    index, = proxy.match(
+    (index,) = proxy.match(
         proxy.index(0, column),
         QtCore.Qt.DisplayRole,
         target,
@@ -433,9 +436,9 @@ def test_table_addition(sample):
     table = epyqlib.pm.parametermodel.Table()
     sample.group_a.append_child(table)
 
-    seconds = epyqlib.pm.parametermodel.Array(name='seconds')
+    seconds = epyqlib.pm.parametermodel.Array(name="seconds")
     table.append_child(seconds)
-    hertz = epyqlib.pm.parametermodel.Array(name='hertz')
+    hertz = epyqlib.pm.parametermodel.Array(name="hertz")
     table.append_child(hertz)
 
     letters_reference = epyqlib.pm.parametermodel.TableEnumerationReference()
@@ -451,12 +454,12 @@ def test_table_addition(sample):
 
 def test_table_add_enumeration_with_uuid(sample):
     punctuation_enumeration = epyqlib.pm.parametermodel.Enumeration(
-        name='punctuation',
+        name="punctuation",
     )
     sample.enumerations.append_child(punctuation_enumeration)
     punctuation_enumerators = {
         punctuation: epyqlib.pm.parametermodel.Enumerator(name=punctuation)
-        for punctuation in '!@#$%^'
+        for punctuation in "!@#$%^"
     }
     for punctuation, enumerator in sorted(punctuation_enumerators.items()):
         punctuation_enumeration.append_child(enumerator)
@@ -477,7 +480,7 @@ def verify_table_automatic_groups(sample):
 
     assert len(groups) == 1
 
-    group, = groups
+    (group,) = groups
 
     enumeration_references = [
         child
@@ -487,8 +490,8 @@ def verify_table_automatic_groups(sample):
 
     enumerations = []
     for enumeration_reference in enumeration_references:
-        enumeration, = sample.root.nodes_by_attribute(
-            attribute_name='uuid',
+        (enumeration,) = sample.root.nodes_by_attribute(
+            attribute_name="uuid",
             attribute_value=enumeration_reference.enumeration_uuid,
         )
         enumerations.append(enumeration)
@@ -504,8 +507,7 @@ def verify_table_automatic_groups(sample):
         enumerations[0].children,
     )
     for child, enumerator in zipped:
-        print('checking: {}'.format((
-            enumerator.name)))
+        print("checking: {}".format((enumerator.name)))
         assert child.name == enumerator.name
 
         zipped = itertools.zip_longest(
@@ -513,8 +515,7 @@ def verify_table_automatic_groups(sample):
             enumerations[1].children,
         )
         for subchild, subenumerator in zipped:
-            print('checking: {}'.format((
-                enumerator.name, subenumerator.name)))
+            print("checking: {}".format((enumerator.name, subenumerator.name)))
             assert subchild.name == subenumerator.name
 
             zipped = itertools.zip_longest(
@@ -522,9 +523,11 @@ def verify_table_automatic_groups(sample):
                 arrays,
             )
             for subsubchild, array in zipped:
-                print('checking: {}'.format((
-                                            enumerator.name, subenumerator.name,
-                                            array.name)))
+                print(
+                    "checking: {}".format(
+                        (enumerator.name, subenumerator.name, array.name)
+                    )
+                )
                 assert subsubchild.name == array.name
 
                 zipped = itertools.zip_longest(
@@ -532,7 +535,16 @@ def verify_table_automatic_groups(sample):
                     array.children,
                 )
                 for subsubsubchild, element in zipped:
-                    print('checking: {}'.format((enumerator.name, subenumerator.name, array.name, element.name)))
+                    print(
+                        "checking: {}".format(
+                            (
+                                enumerator.name,
+                                subenumerator.name,
+                                array.name,
+                                element.name,
+                            )
+                        )
+                    )
                     assert subsubsubchild.name == element.name
 
 
@@ -542,8 +554,8 @@ def test_table_automatic_groups(sample):
 
 def test_table_automatic_groups_add_another(sample):
     array_c = epyqlib.pm.parametermodel.Array(
-        name='Table Array A',
-        uuid='eb812b66-f98b-4e8f-a7e8-4f76c853e437',
+        name="Table Array A",
+        uuid="eb812b66-f98b-4e8f-a7e8-4f76c853e437",
     )
 
     sample.table.append_child(array_c)
@@ -552,18 +564,22 @@ def test_table_automatic_groups_add_another(sample):
 
 
 def test_table_update_same_uuid(qapp):
-    root = graham.schema(epyqlib.pm.parametermodel.Root).loads(
-        serialized_sample,
-    ).data
+    root = (
+        graham.schema(epyqlib.pm.parametermodel.Root)
+        .loads(
+            serialized_sample,
+        )
+        .data
+    )
     model = epyqlib.attrsmodel.Model(
         root=root,
         columns=epyqlib.pm.parametermodel.columns,
     )
     root.model = model
 
-    table_a, = root.nodes_by_attribute(
-        attribute_value='Table A',
-        attribute_name='name',
+    (table_a,) = root.nodes_by_attribute(
+        attribute_value="Table A",
+        attribute_name="name",
     )
 
     # TODO: CAMPid 9784566547216435136479765479163496731
@@ -636,8 +652,7 @@ def test_array_update_children_length():
 
 def test_move_enumeration_in_table(sample):
     uuids_before = {
-        node.uuid
-        for node in sample.table.nodes_by_filter(lambda node: True)
+        node.uuid for node in sample.table.nodes_by_filter(lambda node: True)
     }
 
     table_index = sample.model.index_from_node(sample.table)
@@ -649,8 +664,7 @@ def test_move_enumeration_in_table(sample):
 
     sample.table.update()
     uuids_after = {
-        node.uuid
-        for node in sample.table.nodes_by_filter(lambda node: True)
+        node.uuid for node in sample.table.nodes_by_filter(lambda node: True)
     }
 
     assert len(uuids_after) == len(uuids_before)
@@ -672,8 +686,7 @@ def test_move_enumeration_in_table(sample):
 
     sample.table.update()
     uuids_after = {
-        node.uuid
-        for node in sample.table.nodes_by_filter(lambda node: True)
+        node.uuid for node in sample.table.nodes_by_filter(lambda node: True)
     }
 
     assert len(uuids_after) == len(uuids_before)
